@@ -380,6 +380,14 @@ class DiffusionRatingWorkflow(BaseWorkflowVisualQC, ABC):
             from bids import BIDSLayout
             self.bids_layout = BIDSLayout(self.in_dir)
             self.units = diffusion_traverse_bids(self.bids_layout)
+
+            if self.units is None or len(self.units) < 1:
+                print('No valid subjects are found! Exiting.\n'
+                      'Double check the format and integrity of the dataset '
+                      'if this is unexpected.')
+                import sys
+                sys.exit(1)
+
             # file name of each scan is the unique identifier,
             #   as it essentially contains all the key info.
             self.unit_by_id = {basename(sub_data['image']): sub_data
